@@ -50,14 +50,17 @@ class RestApi:
         cooker=None,
         schemas_directory=None,
         document_schemas=None,
+        user_schema=None,
         user_roles="",
         rate_limit_cost_function=None,
         rate_limits_file=None,
         user_can_delete=False,
-        before_user_creation=None,
         before_document_save=None,
         before_document_delete=None,
         update_search_query=None,
+        on_user_creation=None,
+        on_user_validation=None,
+        on_user_update=None,
         url_prefix="",
     ):
         self.database = database
@@ -69,7 +72,10 @@ class RestApi:
 
         self.user_can_delete = user_can_delete
 
-        self.before_user_creation = self._hook_function(before_user_creation)
+        self.on_user_creation = self._hook_function(on_user_creation)
+        self.on_user_validation = self._hook_function(on_user_validation)
+        self.on_user_update = self._hook_function(on_user_update)
+
         self.before_document_save = self._hook_function(before_document_save)
         self.before_document_delete = self._hook_function(before_document_delete)
         self.update_search_query = update_search_query if update_search_query is not None else lambda query: query
@@ -88,7 +94,8 @@ class RestApi:
         else:
             self._schema_validator = None
 
-        self._document_schemas = document_schemas
+        self._document_schemas = [] if document_schemas is None else document_schemas
+        self._user_schema = user_schema
         self._url_prefix = url_prefix
 
         self.allow = allow
@@ -121,10 +128,16 @@ class RestApi:
         if self._cooker is not None and not callable(self._cooker):
             raise ConfigurationError(f"cooker is not callable: {self._cooker}")
 
-        if self._schema_validator and self._document_schemas:
+        if self._schema_validator:
+            self._schema_validator.assert_schema_exists(self._user_schema)
             for filename in self._document_schemas:
-                if not self._schema_validator.exists(filename):
-                    raise FileNotFoundError(f"Schema {filename} does not exists")
+                self._schema_validator.assert_schema_exists(filename)
+        else:
+            if len(self._document_schemas) != 0:
+                raise ConfigurationError("You provide document_schemas wihtout schemas_directory")
+
+            if self._user_schema is not None:
+                raise ConfigurationError("You provide user_schema wihtout schemas_directory")
 
         for role in ("anonymous", "authenticated"):
             if role in self._user_roles:
@@ -164,10 +177,6 @@ class RestApi:
 
         self.database.init_app(app)
 
-        @app.teardown_appcontext
-        def shutdown_session(exception=None):  # pylint: disable=unused-argument
-            self.database.session.remove()
-
     def _init_login_manager(self, app):
         login_manager = LoginManager(app)
         login_manager.anonymous_user = AnonymousUser
@@ -280,10 +289,14 @@ class RestApi:
 
         return result
 
-    def validate_user_schemas(self, data):
+    def validate_document_schemas(self, data):
         if self._schema_validator is not None:
             self._schema_validator.validate(data, *self._document_schemas)
 
+    def validate_user_schema(self, data):
+        if self._schema_validator is not None and self._user_schema is not None:
+            self._schema_validator.validate(data, self._user_schema)
+
     def add_modules(self, app, *modules, url_prefix=None):
         possible_user_roles = self.user_roles | {"anonymous", "authenticated"}
 
