@@ -17,12 +17,14 @@ class Test_UserCreation(BaseTest):
 
         user = r.json["user"]
 
-        assert len(user) == 5, user
+        assert len(user) == 6, user
         assert "id" in user
         assert "ui_preferences" in user
+        assert "creation_date" in user
         assert user["blocked"] is False
         assert user["name"] == name
         assert user["roles"] == []
+        assert re.match(r"\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{6}\+00:00", user["creation_date"])
 
         self.validate_email(user=user, token=token, expected_status=200)
 
@@ -35,7 +37,7 @@ class Test_UserCreation(BaseTest):
 
         r = self.login_user(name, password, expected_status=200)
 
-        assert len(r.json["user"]) == 6, r.json["user"]
+        assert len(r.json["user"]) == 7, r.json["user"]
         assert r.json["user"]["id"] == user["id"]
         assert r.json["user"]["blocked"] is False
         assert r.json["user"]["ui_preferences"] == {}
